==> res-1.0.0.tgz: package/README.md <==
# res

[![NPM version][npm-image]][npm-url]
[![build status][travis-image]][travis-url]
[![Test coverage][codecov-image]][codecov-url]
[![David deps][david-image]][david-url]
[![Known Vulnerabilities][snyk-image]][snyk-url]
[![npm download][download-image]][download-url]

[npm-image]: https://img.shields.io/npm/v/res.svg?style=flat-square
[npm-url]: https://npmjs.org/package/res
[travis-image]: https://img.shields.io/travis/easy-team/res.svg?style=flat-square
[travis-url]: https://travis-ci.org/easy-team/res
[codecov-image]: https://img.shields.io/codecov/c/github/easy-team/res.svg?style=flat-square
[codecov-url]: https://codecov.io/github/easy-team/res?branch=master
[david-image]: https://img.shields.io/david/easy-team/res.svg?style=flat-square
[david-url]: https://david-dm.org/easy-team/res
[snyk-image]: https://snyk.io/test/npm/res/badge.svg?style=flat-square
[snyk-url]: https://snyk.io/test/npm/res
[download-image]: https://img.shields.io/npm/dm/res.svg?style=flat-square
[download-url]: https://npmjs.org/package/res


A Powerful, Simple React Node Web Framework, Front-End and Node of The Application are Written in TypeScript or JavaScript! Everything is Simple!

> You don't need to care about React server-side rendering implementation details and the Webpack + Babel + TypeScript build process. You just need to write React isomorphic applications just like you would write a React front-end application.

## Installation

```bash
$ npm install @easy-team/res --save
```

Node.js >= 8.0.0 required.

## Features

- ✔︎ Based on [Egg](https://eggjs.org/en/intro/index.html) Framework, Powerful, Easy to Expand
- ✔︎ Support React Server Side Render and Client Side Render Modes, Nunjucks & React Render Mode, Rendering Cache, Automatic Downgrade, 
- ✔︎ Front-End and Node of The Application are Written in TypeScript or JavaScript
- ✔︎ Build with Webpack, Auto Building, Hot Reload, Code Splitting, High Speed, Performance Optimization
- ✔︎ Powerful Tool Chain [res-cli](https://github.com/easy-team/res-cli)

## Document

- https://www.yuque.com/easy-team/res

## QuickStart

```bash
$ npm install -g @easy-team/res-cli
$ res init
$ npm install
$ npm run dev
$ open http://localhost:7001
```

## Examples

See [res-awesome](https://github.com/easy-team/res-awesome)

## Links

- https://eggjs.org/en/advanced/framework.html
- https://www.yuque.com/easy-team/res

## License

[MIT](LICENSE)

==> res-2.0.0.tgz: package/README.md <==
# res

[![NPM version][npm-image]][npm-url]
[![build status][travis-image]][travis-url]
[![Test coverage][codecov-image]][codecov-url]
[![npm download][download-image]][download-url]

[npm-image]: https://img.shields.io/npm/v/@easy-team/res.svg?style=flat-square
[npm-url]: https://npmjs.org/package/res
[travis-image]: https://img.shields.io/travis/easy-team/res.svg?style=flat-square
[travis-url]: https://travis-ci.org/easy-team/res
[codecov-image]: https://img.shields.io/codecov/c/github/easy-team/res.svg?style=flat-square
[codecov-url]: https://codecov.io/github/easy-team/res?branch=master
[download-image]: https://img.shields.io/npm/dm/@easy-team/res.svg?style=flat-square
[download-url]: https://npmjs.org/package/@easy-team/res


A Powerful, Simple React Node Web Framework, Front-End and Node of The Application are Written in TypeScript or JavaScript! Everything is Simple!

> You don't need to care about React server-side rendering implementation details and the Webpack + Babel + TypeScript build process. You just need to write React isomorphic applications just like you would write a React front-end application.

## Installation

```bash
$ npm install @easy-team/res --save
```

Node.js >= 8.0.0 required.

## Features

- ✔︎ Based on [Egg](https://eggjs.org/en/intro/index.html) Framework, Powerful, Easy to Expand
- ✔︎ Support React Server Side Render and Client Side Render Modes, Nunjucks & React Render Mode, Rendering Cache, Automatic Downgrade, 
- ✔︎ Front-End and Node of The Application are Written in TypeScript or JavaScript
- ✔︎ Build with Webpack, Auto Building, Hot Reload, Code Splitting, High Speed, Performance Optimization
- ✔︎ Powerful Tool Chain [res-cli](https://github.com/easy-team/res-cli)

## Document

- https://www.yuque.com/easy-team/res

## QuickStart

```bash
$ npm install -g @easy-team/res-cli
$ res init
$ npm install
$ npm run dev
$ open http://localhost:7001
```

## Examples

See [res-awesome](https://github.com/easy-team/res-awesome)

## Links

- https://eggjs.org/en/advanced/framework.html
- https://www.yuque.com/easy-team/res

## License

[MIT](LICENSE)
